# dj-core-drf

[![PyPI](https://img.shields.io/pypi/pyversions/dj-core-drf.svg)](https://pypi.org/project/dj-core-drf/)
[![PyPI](https://img.shields.io/pypi/v/dj-core-drf.svg)](https://pypi.org/project/dj-core-drf/)
[![Updates](https://pyup.io/repos/github/ionata/dj-core-drf/shield.svg)](https://pyup.io/repos/github/ionata/dj-core-drf/)

DRF core app

Utilises dj-core and adds in automatic addition of REST endpoints
